#!/usr/bin/env python3
import sys

sys.path.append(".")
sys.path.append("/usr/local/lib/python3.10/site-packages")
sys.path.append("/usr/local/lib/python3.9/site-packages")
sys.path.append("/usr/local/lib/python3.8/site-packages")
